@@ -4,12 +4,13 @@
 """
 from pyeole.process import system_code
 
-def dump_sql_file(mysql_root_pwd, filename, database=""):
+def dump_sql_file(mysql_root_pwd, filename, database="", inject=''):
     """
         Dump un fichier .sql dans la base
     """
     mysql_cmd = ['mysql', '--defaults-file=/etc/mysql/debian.cnf', database]
-    sql_code = file(filename).read()
+    sql_code = inject
+    sql_code += file(filename).read()
     return system_code(mysql_cmd, stdin=sql_code, container='mysql')
 
 def dump_sql_file2(filename, database='', default_file='/etc/mysql/debian.cnf'):
